History: ${c.group.display_name} History: ${c.group.display_name}

### Revisions

### Error: ${c.error}

| Revision | Timestamp | Author | Log Message
--- | --- | --- | --- | ---
${h.radio("selected1", revision_dict['id'], checked=(index == 0))} ${h.radio("selected2", revision_dict['id'], checked=(index == len(c.group_revisions)-1))} | ${revision_dict['id']} | ${revision_dict['timestamp']} | ${h.linked_user(revision_dict['author'])} | ${revision_dict['message']}